@@ -11,14 +11,20 @@
 #include "kunitconversion/kunitconversion_export.h"
 #include "unit.h"
 #include "value.h"
+
 #include <QExplicitlySharedDataPointer>
+#include <QObject>
 #include <QString>
 #include <QStringList>
+
 #include <chrono>
 
+class QNetworkReply;
+
 namespace KUnitConversion
 {
 class UnitCategoryPrivate;
+class UpdateJob;
 
 /**
  * @short Class to define a category of units of measurement
@@ -44,35 +50,18 @@ public:
      **/
     UnitCategory(const UnitCategory &other);
 
-    // TODO KF6: remove virtual
-    virtual ~UnitCategory();
+    ~UnitCategory();
 
     /**
      * Assignment operator, assign @p other to this.
      **/
     UnitCategory &operator=(const UnitCategory &other);
 
-    // TODO KF6: de-inline
-#ifdef Q_COMPILER_RVALUE_REFS
     /**
      * Move-assigns @p other to this UnitCategory instance, transferring the
      * ownership of the managed pointer to this instance.
      **/
-    UnitCategory &operator=(UnitCategory &&other)
-    {
-        swap(other);
-        return *this;
-    }
-#endif
-
-    // TODO KF6: remove
-    /**
-     * Swaps this UnitCategory with @p other. This function is very fast and never fails.
-     **/
-    void swap(UnitCategory &other)
-    {
-        d.swap(other.d);
-    }
+    UnitCategory &operator=(UnitCategory &&other);
 
     /**
      * @return @c true if this UnitCategory is equal to the @p other UnitCategory.
@@ -155,7 +144,6 @@ public:
      **/
     QStringList allUnits() const;
 
-    // TODO KF6: make const
     /**
      * Convert value to another unit selected by string.
      *
@@ -163,9 +151,8 @@ public:
      * @param toUnit unit to convert to. If empty default unit is used.
      * @return converted value
      **/
-    Value convert(const Value &value, const QString &toUnit = QString());
+    Value convert(const Value &value, const QString &toUnit = QString()) const;
 
-    // TODO KF6: make const
     /**
      * Convert value to another unit selected by enum.
      *
@@ -173,9 +160,8 @@ public:
      * @param toUnit unit to convert to.
      * @return converted value
      **/
-    Value convert(const Value &value, UnitId toUnit);
+    Value convert(const Value &value, UnitId toUnit) const;
 
-    // TODO KF6: make const, remove virtual
     /**
      * Convert value to another unit.
      *
@@ -183,27 +169,31 @@ public:
      * @param toUnit unit to be used for conversion
      * @return converted value
      **/
-    virtual Value convert(const Value &value, const Unit &toUnit);
+    Value convert(const Value &value, const Unit &toUnit) const;
 
     /**
      * @return true if category has conversion table that needs to be updated via online access, otherwise false
+     * @see syncConversionTable()
      */
     bool hasOnlineConversionTable() const;
 
     /**
-     * Explicit request to sync conversion table when it is older than @p updateSkipPeriod.
+     * Request an update of the online conversion table when it is older than @p updateSkipPeriod.
      *
-     * This method is supposed to be called at a convenient time at application startup. Yet it is
-     * safe to already do unit conversions that require an up-to-date conversion table (like currency).
-     * Those conversions yet block internally until the table is up-to-date.
+     * Returned jobs are automatically deleted, ie. it is safe to ignore the return value if you
+     * do not care about being notified about the completion (or failure) of the update process.
+     * Calling this method while another update is already in progress will not trigger another update
+     * but instead allows you to watch the already ongoing update.
+     * Performing conversions before the update has completed will return results based on the old
+     * conversion table, if available.
+     *
+     * @note This method must be called from the main thread!
+     *
+     * @returns an UpdateJob if an update is necessary or already running, @c nullptr otherwise.
+     * @see UpdateJob
+     * @since 6.0
      */
-    void syncConversionTable(std::chrono::seconds updateSkipPeriod);
-
-protected:
-    // TODO KF6: remove those three
-    void addDefaultUnit(const Unit &unit);
-    void addCommonUnit(const Unit &unit);
-    void addUnit(const Unit &unit);
+    UpdateJob* syncConversionTable(std::chrono::seconds updateSkipPeriod = std::chrono::hours(24));
 
 private:
     friend class Unit;
@@ -215,6 +205,34 @@ protected:
     QExplicitlySharedDataPointer<UnitCategoryPrivate> d;
 };
 
+
+/**
+ * Dynamic conversion data update job.
+ * Created via the factory methods in KUnitConversion::Updater, useful for
+ * getting notified about an update having completed.
+ * Update jobs are automatically deleted on completion, but it is also save to delete
+ * instances manually.
+ *
+ * @see UnitCategory
+ * @since 6.0
+ */
+class KUNITCONVERSION_EXPORT UpdateJob : public QObject
+{
+    Q_OBJECT
+public:
+    ~UpdateJob();
+
+Q_SIGNALS:
+    void finished();
+
+private:
+    friend class UnitCategoryPrivate;
+    explicit UpdateJob(QNetworkReply *dd);
+    QNetworkReply *d;
+};
+
 } // KUnitConversion namespace
 
+Q_DECLARE_TYPEINFO(KUnitConversion::UnitCategory, Q_RELOCATABLE_TYPE);
+
 #endif
